==> cobs-0.8.tgz: cobs-0.8/gb/subread.php <==
<?php 
 /**** ñ ********/
  //ҳ
 require("config.php");
 $PROGNAME="read.php";
  //Tableر
  //ÿһҳı
 $PGNUM=500;//һ¾Բ500
 // Primary Key	
 $PKEY="oid";
 /******** parse  #mt 1:1-3 *****/
 function parsed($VERSION,$tok)
 {
      $LIMIT="";
      $gtok=split("-",$tok);
      //$gtok = strtok ($tok,"-");
      $LIMIT="or ($VERSION.sec>=$gtok[0] and $VERSION.sec<=$gtok[1]) ";
      return($LIMIT);
 }
 function outbible($db_conn,$VERSION,$chineses,$chap,$sec,$chap2,$sec2)
{
 if (!isset($VERSION)) $VERSION="unv";
 if (!isset($strongflag)) $strongflag=0;
 if ($strongflag) $sf=0;
 else $sf=1;
 if (!isset($TABFLAG)) $TABFLAG=0;
 if ($TABFLAG) $TF=0;
 else $TF=1;
  $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 /*****ȷǷID*******/
 if (isset($id))
 {
  $QID="select main.chineses, $VERSION.chap from $VERSION,main where main.engs=$VERSION.engs and $VERSION.id=$id"; 

  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ͽѯ $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $chineses=$ARAW[0];
  $chap=$ARAW[1];
  db_FreeResult($result);
 }
 
  //Queryָ
 if ($chap2>0)  //# mt 1:1-3:4
 {
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap and $VERSION.sec=$sec"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ͽѯ $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $bid=$ARAW[0];
  db_FreeResult($result);
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap2 and $VERSION.sec=$sec2"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ͽѯ $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $eid=$ARAW[0];
  db_FreeResult($result);
  $BLIMIT="$VERSION.id>=$bid and $VERSION.id<=$eid";
 }
 elseif (isset($sec))  //# mt 1:1-3,4,8
   {
	if (strstr($sec,","))
	{
	    $tok = strtok ($sec,",");
	    $SLIMIT="";
	    while (!($tok === FALSE)) // #mt 1:1,2,5,7
	    {
		if (strstr($tok,"-")) // #mt 1:1-3,6,10
		  $SLIMIT=$SLIMIT.parsed($VERSION,$tok);
		else 
		   $SLIMIT=$SLIMIT."or $VERSION.sec=$tok ";
	        $tok = strtok (",");
            }
	    $SLIMIT=substr($SLIMIT,2);
	    $BLIMIT="$VERSION.chap=$chap and ( $SLIMIT )";
	}
	elseif (strstr($sec,"-"))
        {
	    $tok = strtok ($sec,"-");
	    $BLIMIT="$VERSION.chap=$chap and ($VERSION.sec>=$tok and ";
	    $tok = strtok ("-");
	    $BLIMIT=$BLIMIT."$VERSION.sec<=$tok)";
	}
	else
		$BLIMIT="$VERSION.chap=$chap and $VERSION.sec=$sec";
   }
 else $BLIMIT="$VERSION.chap=$chap"; //normal
 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 /******** ʼϿ ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ͽѯ $QUERY !";
                        exit;
 }
 $numrow=pg_NumRows($result);  
 /****** ǳ *********/
 if ($numrow>500)
   {
   	echo " $numrow ʣ̫ˣ޸Ĳѯٲ飡";
	exit;
   }
 if ($numrow==0)
   {
   	echo "鲻κϣ޸Ĳѯٲ飡";
	exit;
   }
 $numfield=pg_NumFields($result);
 /****ӡ *****/
 $TEXTT="";
 for($a=0;$a<$numrow;$a++)
   {
      $ARAW=pg_fetch_row($result,$a); //ȡһʼ¼
      $special=htmlspecialchars($ARAW[2]);
      $TEXTT=$TEXTT.$special;
   }
   return $TEXTT;
}
?>

==> cobs-0.9.tgz: cobs-0.9/gb/subread.php <==
<?php 
 /**** ñ ********/
  //ҳ
 require("config.php");
 $PROGNAME="read.php";
  //Tableر
  //ÿһҳı
 $PGNUM=500;//һ¾Բ500
 // Primary Key	
 $PKEY="oid";
 /******** parse  #mt 1:1-3 *****/
 function parsed($VERSION,$tok)
 {
      $LIMIT="";
      $gtok=split("-",$tok);
      //$gtok = strtok ($tok,"-");
      $LIMIT="or ($VERSION.sec>=$gtok[0] and $VERSION.sec<=$gtok[1]) ";
      return($LIMIT);
 }
 function outbible($db_conn,$VERSION,$chineses,$chap,$sec,$chap2,$sec2)
{
 if (!isset($VERSION)) $VERSION="unv";
 if (!isset($strongflag)) $strongflag=0;
 if ($strongflag) $sf=0;
 else $sf=1;
 if (!isset($TABFLAG)) $TABFLAG=0;
 if ($TABFLAG) $TF=0;
 else $TF=1;
  $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 /*****ȷǷID*******/
 if (isset($id))
 {
  $QID="select main.chineses, $VERSION.chap from $VERSION,main where main.engs=$VERSION.engs and $VERSION.id=$id"; 

  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ͽѯ $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $chineses=$ARAW[0];
  $chap=$ARAW[1];
  db_FreeResult($result);
 }
 
  //Queryָ
 if ($chap2>0)  //# mt 1:1-3:4
 {
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap and $VERSION.sec=$sec"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ͽѯ $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $bid=$ARAW[0];
  db_FreeResult($result);
  $QID="select $VERSION.id from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $VERSION.chap=$chap2 and $VERSION.sec=$sec2"; 
  $result=db_exec($db_conn,$QID);
  if (!$result){
                        echo "Ͽѯ $QID !";
                        exit;
  }
  $ARAW=db_fetch_row($result,0);
  $eid=$ARAW[0];
  db_FreeResult($result);
  $BLIMIT="$VERSION.id>=$bid and $VERSION.id<=$eid";
 }
 elseif (isset($sec))  //# mt 1:1-3,4,8
   {
	if (strstr($sec,","))
	{
	    $tok = strtok ($sec,",");
	    $SLIMIT="";
	    while (!($tok === FALSE)) // #mt 1:1,2,5,7
	    {
		if (strstr($tok,"-")) // #mt 1:1-3,6,10
		  $SLIMIT=$SLIMIT.parsed($VERSION,$tok);
		else 
		   $SLIMIT=$SLIMIT."or $VERSION.sec=$tok ";
	        $tok = strtok (",");
            }
	    $SLIMIT=substr($SLIMIT,2);
	    $BLIMIT="$VERSION.chap=$chap and ( $SLIMIT )";
	}
	elseif (strstr($sec,"-"))
        {
	    $tok = strtok ($sec,"-");
	    $BLIMIT="$VERSION.chap=$chap and ($VERSION.sec>=$tok and ";
	    $tok = strtok ("-");
	    $BLIMIT=$BLIMIT."$VERSION.sec<=$tok)";
	}
	else
		$BLIMIT="$VERSION.chap=$chap and $VERSION.sec=$sec";
   }
 else $BLIMIT="$VERSION.chap=$chap"; //normal
 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,main.engs from $VERSION,main where main.engs=$VERSION.engs and main.chineses='$chineses' and $BLIMIT order by $VERSION.id"; 
 /******** ʼϿ ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ͽѯ $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ǳ *********/
 if ($numrow>500)
   {
   	echo " $numrow ʣ̫ˣ޸Ĳѯٲ飡";
	exit;
   }
 if ($numrow==0)
   {
   	echo "鲻κϣ޸Ĳѯٲ飡";
	exit;
   }
 $numfield=db_NumFields($result);
 /****ӡ *****/
 $TEXTT="";
 for($a=0;$a<$numrow;$a++)
   {
      $ARAW=db_fetch_row($result,$a); //ȡһʼ¼
      $special=htmlspecialchars($ARAW[2]);
      $TEXTT=$TEXTT.$special;
   }
   return $TEXTT;
}
?>
